@@ -51,6 +51,7 @@ racurve <-  function(matrix, main = "Rank-abundance diagram", nlab = 0, ylog = F
     if(ylog == TRUE) {
       plot(rel.abund, xlab="Abundance Rank", ylab="Relative abundance",
            main=main, log="y")
+      lines(rel.abund)
       if(nlab != 0) {
         text(head(rel.abund, n = nlab), labels = labels, pos = 4, cex = 0.7)
       }
@@ -58,6 +59,7 @@ racurve <-  function(matrix, main = "Rank-abundance diagram", nlab = 0, ylog = F
     } else {
       plot(rel.abund, xlab="Abundance Rank", ylab="Relative abundance",
            main=main)
+      lines(rel.abund)
       if(nlab != 0) {
         text(head(rel.abund, n = nlab), labels = labels, pos = 4, cex = 0.7)
       }
@@ -67,6 +69,7 @@ racurve <-  function(matrix, main = "Rank-abundance diagram", nlab = 0, ylog = F
       if(ylog == TRUE) {
         plot(freq, xlab="Frequency Rank", ylab="Frequency",
              main=main, log="y")
+        lines(freq)
         if(nlab != 0) {
           text(head(freq, n = nlab), labels = labels, pos = 4, cex = 0.7)
         }
@@ -74,6 +77,7 @@ racurve <-  function(matrix, main = "Rank-abundance diagram", nlab = 0, ylog = F
       } else {
         plot(freq, xlab="Frequency Rank", ylab="Frequency",
              main=main)
+        lines(freq)
         if(nlab != 0) {
           text(head(freq, n = nlab), labels = labels, pos = 4, cex = 0.7)
         }
